@@ -62,7 +62,7 @@ class ChannelData(BaseRequestAPI):
                 @invitable
                 @rate_limit_per_user
         '''
-        payload = {
+        payload: dict = {
             'name': name,
             'icon': icon,
             'type': type,
@@ -81,7 +81,7 @@ class ChannelData(BaseRequestAPI):
             'locked': locked,
             'invitable': invitable
         }        
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('PATCH', params=payload, uri=f'/channels/{channel_id}')
         
     def delete_close_channel(self, channel_id) -> dict:
@@ -96,13 +96,13 @@ class ChannelData(BaseRequestAPI):
         limit: int=None,
     ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#get-channel-messages'''
-        payload = {
+        payload: dict = {
             'around': around,
             'before': before,
             'after': after,
             'limit': limit
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('GET', params=payload, uri=f'/channels/{channel_id}/messages')
 
     def get_channel_message(self) -> dict:
@@ -124,7 +124,7 @@ class ChannelData(BaseRequestAPI):
     ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#create-message'''
 
-        payload = {
+        payload: dict = {
             'content': content,
             'tts': tts,
             'allowed_mentions': allowed_mentions,
@@ -135,7 +135,7 @@ class ChannelData(BaseRequestAPI):
             'embeds': embeds,
             'attachments': attachments
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         uri = f'/channels/{channel_id}/messages'
         if files != None:
             return  self._send_file_attachment(method='POST', uri=uri, file_names=files, payload=payload)
@@ -144,46 +144,46 @@ class ChannelData(BaseRequestAPI):
 
     def crosspost_message(self, message_id, channel_id) -> dict:
         '''https://discord.com/developers/docs/resources/channel#crosspost-message'''
-        response = self._request('POST', uri=f'/channels/{channel_id}/messages/{message_id}/crosspost')
+        return self._request('POST', uri=f'/channels/{channel_id}/messages/{message_id}/crosspost')
 
     def create_reaction(self, channel_id, message_id, emoji) -> dict:
         '''https://discord.com/developers/docs/resources/channel#create-reaction
             "The emoji must be URL Encoded or the request will fail with 10014: Unknown Emoji. 
             To use custom emoji, you must encode it in the format name:id with the emoji name and emoji id."
         '''
-        response = self._request('PUT', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/@me')
+        return self._request('PUT', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/@me')
 
     def delete_own_reaction(self, channel_id, message_id, emoji) -> dict:
         '''https://discord.com/developers/docs/resources/channel#delete-own-reaction
             "The emoji must be URL Encoded or the request will fail with 10014: Unknown Emoji. 
             To use custom emoji, you must encode it in the format name:id with the emoji name and emoji id."
         '''
-        response = self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/@me')
+        return self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/@me')
 
     def delete_user_reaction(self, channel_id, message_id, user_id, emoji) -> dict:
         '''https://discord.com/developers/docs/resources/channel#delete-user-reaction
             "The emoji must be URL Encoded or the request will fail with 10014: Unknown Emoji. 
             To use custom emoji, you must encode it in the format name:id with the emoji name and emoji id."
         '''
-        response = self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/{user_id}')
+        return self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/{user_id}')
 
     def get_reactions(self, channel_id, message_id, emoji, after=None, limit: int=None) -> dict:
         '''https://discord.com/developers/docs/resources/channel#get-reactions
             "The emoji must be URL Encoded or the request will fail with 10014: Unknown Emoji. 
             To use custom emoji, you must encode it in the format name:id with the emoji name and emoji id."
         '''
-        response = self._request('GET', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}')
+        return self._request('GET', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}')
 
     def delete_all_reactions(self, channel_id, message_id) -> dict:
         '''https://discord.com/developers/docs/resources/channel#delete-all-reactions'''
-        response = self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions')
+        return self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions')
         
     def delete_all_reactions_for_emoji(self, channel_id, message_id, emoji) -> dict:
         '''https://discord.com/developers/docs/resources/channel#delete-all-reactions-for-emoji
             "The emoji must be URL Encoded or the request will fail with 10014: Unknown Emoji. 
             To use custom emoji, you must encode it in the format name:id with the emoji name and emoji id."
         '''
-        response = self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}')
+        return self._request('DELETE', uri=f'/channels/{channel_id}/messages/{message_id}/reactions/{emoji}')
 
     def edit_message(self,
         channel_id,
@@ -199,7 +199,7 @@ class ChannelData(BaseRequestAPI):
         **kwargs
     ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#edit-message'''
-        payload = {
+        payload: dict = {
             'content': content,
             'flags': flags,
             'allowed_mentions': allowed_mentions,
@@ -208,7 +208,7 @@ class ChannelData(BaseRequestAPI):
             'attachments': attachments,
             'embeds': embeds
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         uri = f'/channels/{channel_id}/messages/{message_id}'
         if files != None:
             return  self._send_file_attachment(method='POST', uri=uri, file_names=files, payload=payload)
@@ -226,12 +226,12 @@ class ChannelData(BaseRequestAPI):
 
     def edit_channel_permissions(self, channel_id, overwrite_id, allow=None, deny=None, type: int=None) -> dict:
         '''https://discord.com/developers/docs/resources/channel#edit-channel-permissions'''
-        payload = {
+        payload: dict = {
             'allow': allow,
             'deny': deny,
             'type': type
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('PUT', params=payload, uri=f'/channels/{channel_id}/permissions/{overwrite_id}')
 
     def get_channel_invites(self, channel_id) -> dict:
@@ -249,7 +249,7 @@ class ChannelData(BaseRequestAPI):
         target_application_id=None,
     ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#create-channel-invite'''
-        payload = {
+        payload: dict = {
             'max_age': max_age,
             'max_uses': max_uses,
             'temporary': temporary,
@@ -258,7 +258,7 @@ class ChannelData(BaseRequestAPI):
             'target_user_id': target_user_id,
             'target_application_id': target_application_id
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('POST', params=payload, uri=f'/channels/{channel_id}/invites')
 
     def delete_channel_permission(self, channel_id, overwrite_id) -> dict:
@@ -267,7 +267,7 @@ class ChannelData(BaseRequestAPI):
 
     def follow_news_channel(self, channel_id, webhook_channel_id) -> dict:
         '''https://discord.com/developers/docs/resources/channel#follow-news-channel'''
-        payload = { 'webhook_channel_id': webhook_channel_id }
+        payload: dict = { 'webhook_channel_id': webhook_channel_id }
         return  self._request('POST', params=payload, uri=f'/channels/{channel_id}/followers')
 
     def trigger_typing_indicatoe(self, channel_id) -> dict:
@@ -288,11 +288,11 @@ class ChannelData(BaseRequestAPI):
 
     def group_dm_add_recipient(self, channel_id, user_id, access_token, nick) -> dict:
         '''https://discord.com/developers/docs/resources/channel#group-dm-add-recipient'''
-        payload = {
+        payload: dict = {
             'access_token': access_token,
             'nick':nick
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('PUT', params=payload, uri=f'/channels/{channel_id}/recipients/{user_id}')
 
     def group_dm_remove_recipient(self, channel_id, user_id) -> dict:
@@ -301,12 +301,12 @@ class ChannelData(BaseRequestAPI):
 
     def start_thread_with_message(self, channel_id, user_id, name: str, auto_archive_duration: int=None, rate_limit_per_user: int=None) -> dict:
         '''https://discord.com/developers/docs/resources/channel#start-thread-with-message'''
-        payload = { 
+        payload: dict = { 
             'name': name,
             'auto_archive_duration': auto_archive_duration,
             'rate_limit_per_user': rate_limit_per_user
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('POST', params=payload, uri=f'/channels/{channel_id}/messages/{message_id}/threads')
 
     def start_thread_without_message(self, 
@@ -317,14 +317,14 @@ class ChannelData(BaseRequestAPI):
         rate_limit_per_user: int=None,
     ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#start-thread-without-message'''
-        payload = { 
+        payload: dict = { 
             'name': name,
             'auto_archive_duration': auto_archive_duration,
             'type': type,
             'invitable': invitable,
             'rate_limit_per_user': rate_limit_per_user
         }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('POST', params=payload, uri=f'/channels/{channel_id}/threads')
 
     def join_thread(self, channel_id) -> dict:
@@ -353,7 +353,7 @@ class ChannelData(BaseRequestAPI):
 
     def list_active_threads(self, channel_id, threads: list, members: list, has_more: bool ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#list-active-threads'''
-        payload = {
+        payload: dict = {
             'threads': threads,
             'members': members,
             'has_more': has_more
@@ -362,18 +362,18 @@ class ChannelData(BaseRequestAPI):
 
     def list_public_archived_threads(self, channel_id, before=None, limit:int=None ) -> dict:
         '''https://discord.com/developers/docs/resources/channel#list-public-archived-threads'''
-        payload = { 'before': before, 'limit': limit}
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = { 'before': before, 'limit': limit}
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('GET', params=params, uri=f'/channels/{channel_id}/threads/archived/public')
 
     def list_private_archived_threads(self, channel_id) -> dict:
         '''https://discord.com/developers/docs/resources/channel#list-private-archived-threads'''
-        payload = { 'before': before, 'limit': limit }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = { 'before': before, 'limit': limit }
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('GET', params=payload, uri=f'/channels/{channel_id}/threads/archived/private')
 
     def list_joined_private_archived_threads(self, channel_id, before=None, limit:int=None) -> dict:
         '''https://discord.com/developers/docs/resources/channel#list-joined-private-archived-threads'''
-        payload = { 'before': before, 'limit': limit }
-        payload = {k:v for k,v in payload.items() if v is not None}
+        payload: dict = { 'before': before, 'limit': limit }
+        payload: dict = {k:v for k,v in payload.items() if v is not None}
         return  self._request('GET', params=payload, uri=f'/channels/{channel_id}/users/@me/threads/archived/private')
\ No newline at end of file
